@@ -2,11 +2,11 @@ import pkgutil
 from dialog import Dialog
 from sys import exit
 import logging
-import logs as logs
-from options import create_parser
+import Simple_Process_REPL.logs as logs
+from Simple_Process_REPL.options import create_parser
 import os
 from platform import system as platform
-import repl as r
+import Simple_Process_REPL.repl as r
 
 import regex as re
 import serial
